==========
Change Log
==========

This document records all notable changes to EazyTV.
This project adheres to `Semantic Versioning <http://semver.org/>`_.

0.3 (2018-05-04)
-------------------

* Added new command : search (search show on EZTV)


0.2 (2018-04-31)
-------------------

* Added new command : showlist (display show available from EZTV)
* Added display show by status (Airing, On Break, Ended, Pending)


0.1 (2018-04-24)
-------------------

* Initial commit
